@@ -20,7 +20,7 @@ use Test2::Util 1.302096 ();
 
 use base qw{ Exporter };
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 $VERSION =~ s/ _ //smxg;
 
 {
@@ -767,7 +767,8 @@ L<Test::More|Test::More>
 
 L<Test2::V0|Test2::V0>
 
-L<Test2::Require|Test2::Require>
+L<Test2::Require|Test2::Require>, especially
+L<Test2::Require::Module|Test2::Require::Module>.
 
 L<Test2::Manual::Testing::Migrating|Test2::Manual::Testing::Migrating>
 
@@ -786,11 +787,11 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019-2022 by Thomas R. Wyant, III
+Copyright (C) 2019-2026 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the directory LICENSES.
+of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GPL>.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
